Images class

Constructors

Images({required String url, required String action})
Images.fromJson(String source)
factory
Images.fromMap(Map<String, dynamic> map)
factory

Properties

action String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

copyWith({String? url, String? action}) Images
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override