SliderBase class

Implemented types

Constructors

SliderBase({required List<Images> images})
SliderBase.fromJson(String source)
factory
SliderBase.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
images List<Images>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Widget
override
copyWith({List<Images>? images}) SliderBase
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override