ComponentsProperties class
Constructors
- ComponentsProperties({num? sliderBorderRadius, Double? addBorderRadius, CarouselOptions? carouselOptions, EdgeInsetsGeometry? componentsPadding})
Properties
- addBorderRadius → Double?
-
final
- carouselOptions ↔ CarouselOptions?
-
getter/setter pair
- componentsPadding ↔ EdgeInsetsGeometry?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliderBorderRadius → num?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited